==> classpath-0.17.tar.gz: classpath-0.17/java/awt/peer/FramePeer.java <==
/* FramePeer.java -- Interface for frame peers
   Copyright (C) 1999 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.awt.peer;

import java.awt.Image;
import java.awt.MenuBar;
import java.awt.Rectangle;

public interface FramePeer extends WindowPeer
{
  void setIconImage(Image image);
  void setMenuBar(MenuBar mb);
  void setResizable(boolean resizable);
  void setTitle(String title);
  int getState();
  void setState(int state);
  void setMaximizedBounds(Rectangle r);
} // interface FramePeer

==> classpath-0.90.tar.gz: classpath-0.90/java/awt/peer/FramePeer.java <==
/* FramePeer.java -- Interface for frame peers
   Copyright (C) 1999 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.awt.peer;

import java.awt.Image;
import java.awt.MenuBar;
import java.awt.Rectangle;

public interface FramePeer extends WindowPeer
{
  void setIconImage(Image image);
  void setMenuBar(MenuBar mb);
  void setResizable(boolean resizable);
  void setTitle(String title);
  int getState();
  void setState(int state);
  void setMaximizedBounds(Rectangle r);
  
  /**
   * Check if this frame peer supports being restacked.
   * 
   * @return true if this frame peer can be restacked,
   * false otherwise
   * @since 1.5
   */
  boolean isRestackSupported();
  
  /**
   * Sets the bounds of this frame peer.
   * 
   * @param x the new x co-ordinate
   * @param y the new y co-ordinate
   * @param width the new width
   * @param height the new height
   * @since 1.5
   */
  void setBoundsPrivate(int x, int y, int width, int height);
} // interface FramePeer
